@@ -4,7 +4,7 @@ use 5.008;
 
 package DBIx::Locker;
 # ABSTRACT: locks for db resources that might not be totally insane
-$DBIx::Locker::VERSION = '0.100117';
+$DBIx::Locker::VERSION = '0.100118';
 use Carp ();
 use DBI;
 use Data::GUID ();
@@ -45,7 +45,7 @@ use Sys::Hostname ();
 #pod
 #pod =item * C<created> datetime
 #pod
-#pod =item * C<exires> datetime
+#pod =item * C<expires> datetime
 #pod
 #pod =item * C<locked_by> text
 #pod
@@ -258,7 +258,7 @@ DBIx::Locker - locks for db resources that might not be totally insane
 
 =head1 VERSION
 
-version 0.100117
+version 0.100118
 
 =head1 DESCRIPTION
 
@@ -341,7 +341,7 @@ columns:
 
 =item * C<created> datetime
 
-=item * C<exires> datetime
+=item * C<expires> datetime
 
 =item * C<locked_by> text
 
@@ -353,9 +353,33 @@ See the C<sql> directory included in this dist for DDL for your database.
 
 Ricardo SIGNES <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Arthur Axel 'fREW' Schmidt Chris Nehren Hans Dieter Pearcey Sergiy Borodych
+
+=over 4
+
+=item *
+
+Arthur Axel 'fREW' Schmidt <frioux@gmail.com>
+
+=item *
+
+Chris Nehren <apeiron@cpan.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@cpan.org>
+
+=item *
+
+Sergiy Borodych <sergiy.borodych@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
