@@ -4,7 +4,7 @@ use 5.008;
 # ABSTRACT: a live resource lock
 
 package DBIx::Locker::Lock;
-$DBIx::Locker::Lock::VERSION = '0.100117';
+$DBIx::Locker::Lock::VERSION = '0.100118';
 use Carp ();
 use Sub::Install ();
 
@@ -72,7 +72,7 @@ BEGIN {
 #pod using this method as a mutator:
 #pod
 #pod   # expire one hour from now, no matter what initial expiration was
-#pod   $lock->expired(time + 3600);
+#pod   $lock->expires(time + 3600);
 #pod
 #pod When updating the expiration time, if the given expiration time is not a valid
 #pod unix time, or if the expiration cannot be updated, an exception will be raised.
@@ -169,7 +169,7 @@ DBIx::Locker::Lock - a live resource lock
 
 =head1 VERSION
 
-version 0.100117
+version 0.100118
 
 =head1 METHODS
 
@@ -206,7 +206,7 @@ L</new> -- unless expiration has been changed.  Expiration can be changed by
 using this method as a mutator:
 
   # expire one hour from now, no matter what initial expiration was
-  $lock->expired(time + 3600);
+  $lock->expires(time + 3600);
 
 When updating the expiration time, if the given expiration time is not a valid
 unix time, or if the expiration cannot be updated, an exception will be raised.
@@ -230,7 +230,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
